@@ -129,24 +129,30 @@ sensitivity_cumulative <- function(ma_obj, sort_method = "weight", ...){
                cred_method <- ma_obj$barebones$inputs$cred_method
 
                if(es_type == "es"){
-                    es_data <- data.frame(sample_id = sample_id[[i]],
-                                          yi = yi[[i]],
+                    es_data <- data.frame(yi = yi[[i]],
                                           n = n[[i]])
+                    es_data$vi <- vi_xy[[i]]
+                    es_data$weight <- wt_xy[[i]]
+                    if(!is.null(sample_id[[i]])) add_column(es_data, sample_id = sample_id[[i]], .before = "yi")
                }
                if(es_type == "r"){
-                    es_data <- data.frame(sample_id = sample_id[[i]],
-                                          rxy = rxy[[i]],
+                    es_data <- data.frame(rxy = rxy[[i]],
                                           n = n[[i]])
                     es_data$n_adj <- n_adj[[i]]
+                    es_data$vi <- vi_xy[[i]]
+                    es_data$weight <- wt_xy[[i]]
+                    if(!is.null(sample_id[[i]])) add_column(es_data, sample_id = sample_id[[i]], .before = "rxy")
                }
                if(es_type == "d"){
-                    es_data <- data.frame(sample_id = sample_id[[i]],
-                                          d = d[[i]],
-                                          n1 = n1[[i]],
-                                          n2 = n2[[i]],
-                                          n = n[[i]],
-                                          pi = pi[[i]])
+                    es_data <- data.frame(d = d[[i]],
+                                          n1 = n1[[i]])
+                    es_data$n2 <- n2[[i]]
+                    es_data$n <- n[[i]]
+                    es_data$pi <- pi[[i]]
                     es_data$n_adj <- n_adj[[i]]
+                    es_data$vi <- vi_xy[[i]]
+                    es_data$weight <- wt_xy[[i]]
+                    if(!is.null(sample_id[[i]])) add_column(es_data, sample_id = sample_id[[i]], .before = "d")
                }
 
                if(any(class_ma == "ma_ic")){
@@ -243,12 +249,12 @@ sensitivity_cumulative <- function(ma_obj, sort_method = "weight", ...){
                     }
 
                     if(any(class_ma == "ma_ad")){
-                         ma_ad_dump_full <- do.call(ma_r_ad, append(ma_obj$artifact_distribution$inputs, list(.psychmeta_internal_request_datadump = TRUE)))
+                         ma_ad_dump_full <- do.call(.ma_r_ad, append(ma_obj$artifact_distribution$inputs, list(.psychmeta_internal_request_datadump = TRUE)))
                          ma_ad_dump <- ma_ad_dump_full$x
                          ma_ad_dump$art_grid <- ma_ad_dump_full$art_grid
                          ma_arg_list$ma_ad_dump <- ma_ad_dump
 
-                         rep_list <- .separate_repmat(rep_mat = .ma_cumulative(data = es_data, sort_method = sort_method, ma_fun_boot = .ma_r_ad_boot, ma_arg_list = ma_arg_list))
+                         rep_list <- .separate_repmat(rep_mat = .ma_cumulative(data = es_data, sort_method = sort_method, ma_fun_boot = .ma_r_ad_boot, ma_arg_list = ma_arg_list), analysis="cumulative")
 
                          bb_table <- rep_list$barebones
                          ts_table <- rep_list$true_score
